      SUBROUTINE ZCRLOG (LLEN, LOGNAM, TLEN, TLOG, IERR)
C-----------------------------------------------------------------------
C! (re)define a logical name
C# Z2 System
C-----------------------------------------------------------------------
C;  Copyright (C) 1995, 2004
C;  Associated Universities, Inc. Washington DC, USA.
C;
C;  This program is free software; you can redistribute it and/or
C;  modify it under the terms of the GNU General Public License as
C;  published by the Free Software Foundation; either version 2 of
C;  the License, or (at your option) any later version.
C;
C;  This program is distributed in the hope that it will be useful,
C;  but WITHOUT ANY WARRANTY; without even the implied warranty of
C;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C;  GNU General Public License for more details.
C;
C;  You should have received a copy of the GNU General Public
C;  License along with this program; if not, write to the Free
C;  Software Foundation, Inc., 675 Massachusetts Ave, Cambridge,
C;  MA 02139, USA.
C;
C;  Correspondence concerning AIPS should be addressed as follows:
C;         Internet email: aipsmail@nrao.edu.
C;         Postal address: AIPS Project Office
C;                         National Radio Astronomy Observatory
C;                         520 Edgemont Road
C;                         Charlottesville, VA 22903-2475 USA
C-----------------------------------------------------------------------
C   Defines a new logical name (i.e., environment variable) or redefines
C   an old one.
C   Inputs:
C      LLEN     I       Length of lognam (< 65)
C      LOGNAM   H(*)    Logical name
C      TLEN     I       Length of tlen (< 257)
C      TLOG     H(*)    New translated logical name
C   Outputs:
C      IERR     I       Error return code: 0 okay
C                          1 => error
C   Generic version - stubbed
C-----------------------------------------------------------------------
      INTEGER   LLEN, TLEN, IERR
      HOLLERITH LOGNAM(*), TLOG(*)
C
      INCLUDE 'INCS:DMSG.INC'
C-----------------------------------------------------------------------
      IERR = 2
      MSGTXT = 'ZCRLOG REQUIRES LOCAL DEVELOPMENT'
      CALL MSGWRT (8)
C
 999  RETURN
      END
